@@ -131,15 +131,26 @@ impl Image {
     }
 
     pub fn save_bytes(&mut self) -> PyResult<&PyBytes> {
+        let mut img = helpers::dyn_image_from_raw(&self.img);
+        img = image::ImageRgba8(img.to_rgba());
+        let mut buffer = vec![];
+        match img.write_to(&mut buffer, image::ImageOutputFormat::PNG) {
+            Ok(..) => ..,
+            Err(e) => panic!("Error: {}", e),
+        };
         unsafe {
             Python::with_gil(|_py| -> PyResult<&PyBytes> {
                 let npy = Python::assume_gil_acquired();
-                let temp = self.img.get_raw_pixels();
-                let buf = temp.as_slice();
+                let buf = buffer.as_slice();
                 Ok(PyBytes::new(npy, buf))
             })
         }
     }
+
+    pub fn save_base_64(&mut self) -> PyResult<String> {
+        let data = self.img.get_base64();
+        Ok(data)
+    }
 }
 
 #[pyproto]
